@@ -56,12 +56,14 @@ def get_departments(organization_id: int, department_name: str = None) -> dict:
                     obj = Department.objects.filter(pk=i).only("name").first()
                     dic["id"] = obj.id
                     dic["name"] = obj.name
+                    dic["charger_id"] = obj.charger_id
                     dic["show_order"] = obj.show_order
                     lst.append(dic)
             # 最后把部门本身的内容也append到返回列表中
             lst.append({
                 "id": instance.id,
                 "name": instance.name,
+                "charger_id": instance.charger_id,
                 "show_order": instance.show_order
             })
             items.append(lst)
